import { useEffect, useRef, useState as ReactUseState, } from 'react';
function useMountedStateHook() {
    const isMounted = useRef(true);
    useEffect(() => {
        isMounted.current = true;
        return () => {
            isMounted.current = false;
        };
    }, []);
    return (initialValue) => {
        const [state, setState] = ReactUseState(initialValue);
        return [
            state,
            (newValue) => {
                if (!isMounted.current)
                    return;
                setState(newValue);
            },
        ];
    };
}
export default useMountedStateHook;
export const useMountedState = useMountedStateHook;
